@@ -4,7 +4,7 @@
  * includes all common video types and constants.
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: video.h,v 1.32 2001/08/22 17:21:45 massiot Exp $
+ * $Id: video.h,v 1.61 2002/11/25 19:29:10 sam Exp $
  *
  * Authors: Vincent Seguin <seguin@via.ecp.fr>
  *
@@ -24,11 +24,23 @@
  *****************************************************************************/
 
 /*****************************************************************************
- * Requires:
- *  "config.h"
- *  "common.h"
- *  "mtime.h"
+ * plane_t: description of a planar graphic field
  *****************************************************************************/
+typedef struct plane_t
+{
+    uint8_t *p_pixels;                          /* Start of the plane's data */
+
+    /* Variables used for fast memcpy operations */
+    int i_lines;                                          /* Number of lines */
+    int i_pitch;             /* Number of bytes in a line, including margins */
+
+    /* Size of a macropixel, defaults to 1 */
+    int i_pixel_pitch;
+
+    /* Variables used for pictures with margins */
+    int i_visible_pitch;              /* How many visible pixels are there ? */
+
+} plane_t;
 
 /*****************************************************************************
  * picture_t: video picture
@@ -38,51 +50,80 @@
  * Picture type and flags should only be modified by the output thread. Note
  * that an empty picture MUST have its flags set to 0.
  *****************************************************************************/
-typedef struct picture_s
+struct picture_t
 {
+    /* Picture data - data can always be freely modified, but p_data may
+     * NEVER be modified. A direct buffer can be handled as the plugin
+     * wishes, it can even swap p_pixels buffers. */
+    uint8_t        *p_data;
+    void           *p_data_orig;                  /* pointer before memalign */
+    plane_t         p[ VOUT_MAX_PLANES ];       /* description of the planes */
+    int             i_planes;                  /* number of allocated planes */
+
     /* Type and flags - should NOT be modified except by the vout thread */
-    int             i_type;                                  /* picture type */
     int             i_status;                               /* picture flags */
+    int             i_type;                  /* is picture a direct buffer ? */
     int             i_matrix_coefficients;     /* in YUV type, encoding type */
 
     /* Picture management properties - these properties can be modified using
-     * the video output thread API, but should ne be written directly */
+     * the video output thread API, but should never be written directly */
     int             i_refcount;                    /* link reference counter */
     mtime_t         date;                                    /* display date */
-
-    /* Picture static properties - those properties are fixed at initialization
-     * and should NOT be modified */
-    int             i_width;                                /* picture width */
-    int             i_chroma_width;                          /* chroma width */
-    int             i_height;                              /* picture height */
-    int             i_size;                                /* number of pels */
-    int             i_chroma_size;                  /* number of chroma pels */
+    vlc_bool_t      b_force;
 
     /* Picture dynamic properties - those properties can be changed by the
      * decoder */
-    int             i_display_horizontal_offset;   /* ISO/IEC 13818-2 6.3.12 */
-    int             i_display_vertical_offset;     /* ISO/IEC 13818-2 6.3.12 */
-    int             i_display_width;                 /* useful picture width */
-    int             i_display_height;               /* useful picture height */
-    int             i_aspect_ratio;                          /* aspect ratio */
+    vlc_bool_t      b_progressive;            /* is it a progressive frame ? */
+    vlc_bool_t      b_repeat_first_field;                         /* RFF bit */
+    vlc_bool_t      b_top_field_first;               /* which field is first */
 
-    /* Picture data - data can always be freely modified. p_data itself
-     * (the pointer) should NEVER be modified. In YUV format, the p_y, p_u and
-     * p_v data pointers refers to different areas of p_data, and should not
-     * be freed */
-    void *          p_data;                                  /* picture data */
-    yuv_data_t *    p_y;        /* pointer to beginning of Y image in p_data */
-    yuv_data_t *    p_u;        /* pointer to beginning of U image in p_data */
-    yuv_data_t *    p_v;        /* pointer to beginning of V image in p_data */
-} picture_t;
+    /* The picture heap we are attached to */
+    picture_heap_t* p_heap;
 
-/* Pictures types */
-#define EMPTY_PICTURE           0     /* picture slot is empty and available */
-#define YUV_420_PICTURE         100                     /* 4:2:0 YUV picture */
-#define YUV_422_PICTURE         101                     /* 4:2:2 YUV picture */
-#define YUV_444_PICTURE         102                     /* 4:4:4 YUV picture */
+    /* Private data - the video output plugin might want to put stuff here to
+     * keep track of the picture */
+    picture_sys_t * p_sys;
+};
 
-/* Pictures status */
+/*****************************************************************************
+ * picture_heap_t: video picture heap, either render (to store pictures used
+ * by the decoder) or output (to store pictures displayed by the vout plugin)
+ *****************************************************************************/
+struct picture_heap_t
+{
+    int i_pictures;                                     /* current heap size */
+
+    /* Picture static properties - those properties are fixed at initialization
+     * and should NOT be modified */
+    unsigned int i_width;                                   /* picture width */
+    unsigned int i_height;                                 /* picture height */
+    vlc_fourcc_t i_chroma;                                 /* picture chroma */
+    unsigned int i_aspect;                                   /* aspect ratio */
+
+    /* Real pictures */
+    picture_t*      pp_picture[VOUT_MAX_PICTURES];               /* pictures */
+    int             i_last_used_pic;                /* last used pic in heap */
+    vlc_bool_t      b_allow_modify_pics;
+
+    /* Stuff used for truecolor RGB planes */
+    int i_rmask, i_rrshift, i_lrshift;
+    int i_gmask, i_rgshift, i_lgshift;
+    int i_bmask, i_rbshift, i_lbshift;
+
+    /* Stuff used for palettized RGB planes */
+    void (* pf_setpalette) ( vout_thread_t *, uint16_t *, uint16_t *, uint16_t * );
+};
+
+/*****************************************************************************
+ * Flags used to describe the status of a picture
+ *****************************************************************************/
+
+/* Picture type */
+#define EMPTY_PICTURE           0                            /* empty buffer */
+#define MEMORY_PICTURE          100                 /* heap-allocated buffer */
+#define DIRECT_PICTURE          200                         /* direct buffer */
+
+/* Picture status */
 #define FREE_PICTURE            0                  /* free and not allocated */
 #define RESERVED_PICTURE        1                  /* allocated and reserved */
 #define RESERVED_DATED_PICTURE  2              /* waiting for DisplayPicture */
@@ -91,11 +132,22 @@ typedef struct picture_s
 #define DISPLAYED_PICTURE       5            /* been displayed but is linked */
 #define DESTROYED_PICTURE       6              /* allocated but no more used */
 
-/* Aspect ratios (ISO/IEC 13818-2 section 6.3.3, table 6-3) */
-#define AR_SQUARE_PICTURE       1                           /* square pixels */
-#define AR_3_4_PICTURE          2                        /* 3:4 picture (TV) */
-#define AR_16_9_PICTURE         3              /* 16:9 picture (wide screen) */
-#define AR_221_1_PICTURE        4                  /* 2.21:1 picture (movie) */
+/*****************************************************************************
+ * Shortcuts to access image components
+ *****************************************************************************/
+
+/* Plane indices */
+#define Y_PLANE      0
+#define U_PLANE      1
+#define V_PLANE      2
+
+/* Shortcuts */
+#define Y_PIXELS     p[Y_PLANE].p_pixels
+#define Y_PITCH      p[Y_PLANE].i_pitch
+#define U_PIXELS     p[U_PLANE].p_pixels
+#define U_PITCH      p[U_PLANE].i_pitch
+#define V_PIXELS     p[V_PLANE].p_pixels
+#define V_PITCH      p[V_PLANE].i_pitch
 
 /*****************************************************************************
  * subpicture_t: video subtitle
@@ -105,18 +157,17 @@ typedef struct picture_s
  * Subtitle type and flags should only be modified by the output thread. Note
  * that an empty subtitle MUST have its flags set to 0.
  *****************************************************************************/
-typedef struct subpicture_s
+struct subpicture_t
 {
     /* Type and flags - should NOT be modified except by the vout thread */
     int             i_type;                                          /* type */
     int             i_status;                                       /* flags */
-    int             i_size;                                     /* data size */
-    struct subpicture_s *   p_next;         /* next subtitle to be displayed */
+    subpicture_t *  p_next;                 /* next subtitle to be displayed */
 
     /* Date properties */
     mtime_t         i_start;                    /* beginning of display date */
     mtime_t         i_stop;                           /* end of display date */
-    boolean_t       b_ephemer;             /* does the subtitle have a TTL ? */
+    vlc_bool_t      b_ephemer;             /* does the subtitle have a TTL ? */
 
     /* Display properties - these properties are only indicative and may be
      * changed by the video output thread, or simply ignored depending of the
@@ -125,9 +176,8 @@ typedef struct subpicture_s
     int             i_y;                   /* offset from alignment position */
     int             i_width;                                /* picture width */
     int             i_height;                              /* picture height */
-    int             i_horizontal_align;              /* horizontal alignment */
-    int             i_vertical_align;                  /* vertical alignment */
 
+#if 0
     /* Additionnal properties depending of the subpicture type */
     union
     {
@@ -135,48 +185,30 @@ typedef struct subpicture_s
          * format */
         struct
         {
-            p_vout_font_t       p_font;            /* font, NULL for default */
+            vout_font_t *       p_font;            /* font, NULL for default */
             int                 i_style;                       /* text style */
-            u32                 i_char_color;             /* character color */
-            u32                 i_border_color;              /* border color */
-            u32                 i_bg_color;              /* background color */
+            uint32_t            i_char_color;             /* character color */
+            uint32_t            i_border_color;              /* border color */
+            uint32_t            i_bg_color;              /* background color */
         } text;
-        /* DVD subpicture units properties */
-        struct
-        {
-            int                 i_offset[2];         /* byte offsets to data */
-        } spu;
     } type;
+#endif
 
-    /* Subpicture data, format depends of type - data can always be freely
-     * modified. p_data itself (the pointer) should NEVER be modified. */
-    void *          p_data;                               /* subpicture data */
-} subpicture_t;
+    /* The subpicture rendering and destruction routines */
+    void ( *pf_render )  ( vout_thread_t *, picture_t *, const subpicture_t * );
+    void ( *pf_destroy ) ( subpicture_t * );
+
+    /* Private data - the subtitle plugin might want to put stuff here to
+     * keep track of the subpicture */
+    subpicture_sys_t *p_sys;                              /* subpicture data */
+};
 
 /* Subpicture type */
 #define EMPTY_SUBPICTURE       0     /* subtitle slot is empty and available */
-#define DVD_SUBPICTURE         100                    /* DVD subpicture unit */
-#define TEXT_SUBPICTURE        200                       /* single line text */
+#define MEMORY_SUBPICTURE      100            /* subpicture stored in memory */
 
 /* Subpicture status */
 #define FREE_SUBPICTURE        0                   /* free and not allocated */
 #define RESERVED_SUBPICTURE    1                   /* allocated and reserved */
 #define READY_SUBPICTURE       2                        /* ready for display */
-#define DESTROYED_SUBPICTURE   3           /* allocated but not used anymore */
-
-/* Alignment types */
-#define RIGHT_ALIGN            10                 /* x is absolute for right */
-#define LEFT_ALIGN             11                  /* x is absolute for left */
-#define RIGHT_RALIGN           12      /* x is relative for right from right */
-#define LEFT_RALIGN            13        /* x is relative for left from left */
-
-#define CENTER_ALIGN           20            /* x, y are absolute for center */
-#define CENTER_RALIGN          21 /* x,y are relative for center from center */
-
-#define BOTTOM_ALIGN           30                /* y is absolute for bottom */
-#define TOP_ALIGN              31                   /* y is absolute for top */
-#define BOTTOM_RALIGN          32    /* y is relative for bottom from bottom */
-#define TOP_RALIGN             33          /* y is relative for top from top */
-#define SUBTITLE_RALIGN        34  /* y is relative for center from subtitle */
-
 
