@@ -2,7 +2,7 @@
  * system.c: helper module for TS, PS and PES management
  *****************************************************************************
  * Copyright (C) 1998-2002 VideoLAN
- * $Id: system.c,v 1.8 2002/12/06 16:34:07 sam Exp $
+ * $Id: system.c,v 1.11 2003/03/09 23:39:05 jlj Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *          Michel Lespinasse <walken@via.ecp.fr>
@@ -187,7 +187,7 @@ static void ParsePES( input_thread_t * p_input, es_descriptor_t * p_es )
             msg_Warn( p_input, "packet corrupted, PES sizes do not match" );
         }
 
-        switch( p_es->i_stream_id )
+        switch( p_header[3] )
         {
         case 0xBC:  /* Program stream map */
         case 0xBE:  /* Padding */
@@ -875,6 +875,24 @@ static es_descriptor_t * ParsePS( input_thread_t * p_input,
                         case REQUESTED_MPEG:
                             input_SelectES( p_input, p_es );
                         }
+#endif
+                    }
+                    else if( (i_id & 0xF8FF) == 0x88BD )
+                    {
+                        p_es->i_fourcc = VLC_FOURCC('d','t','s','b');
+                        p_es->i_cat = AUDIO_ES;
+#ifdef AUTO_SPAWN
+                        if( !p_input->stream.b_seekable )
+                        if( config_GetInt( p_input, "audio-channel" )
+                                == ((p_es->i_id & 0x700) >> 8) ||
+                            ( config_GetInt( p_input, "audio-channel" ) < 0
+                              && !((p_es->i_id & 0x700) >> 8)) )
+                        switch( config_GetInt( p_input, "audio-type" ) )
+                        {
+                        case -1:
+                        case REQUESTED_DTS:
+                            input_SelectES( p_input, p_es );
+                        }
 #endif
                     }
                     else if( (i_id & 0xF0FF) == 0x80BD )
@@ -1154,6 +1172,8 @@ static void DemuxTS( input_thread_t * p_input, data_packet_t * p_data,
     es_descriptor_t *   p_es = NULL;
     es_ts_data_t *      p_es_demux = NULL;
     pgrm_ts_data_t *    p_pgrm_demux = NULL;
+    stream_ts_data_t *  p_stream_demux =
+                          (stream_ts_data_t *)p_input->stream.p_demux_data;
 
 #define p (p_data->p_demux_start)
     /* Extract flags values from TS common header. */
@@ -1175,7 +1195,7 @@ static void DemuxTS( input_thread_t * p_input, data_packet_t * p_data,
         }
     }
 
-    p_es= input_FindES( p_input, i_pid );
+    p_es = input_FindES( p_input, i_pid );
 
     if( (p_es != NULL) && (p_es->p_demux_data != NULL) )
     {
@@ -1210,7 +1230,7 @@ static void DemuxTS( input_thread_t * p_input, data_packet_t * p_data,
     /* Don't change the order of the tests : if b_psi then p_pgrm_demux
      * may still be null. Who said it was ugly ?
      * I have written worse. --Meuuh */
-    if( ( p_es  ) &&
+    if( ( p_es ) &&
         ((p_es->p_decoder_fifo != NULL) || b_psi || b_pcr ) )
     {
         p_es->c_packets++;
@@ -1273,7 +1293,7 @@ static void DemuxTS( input_thread_t * p_input, data_packet_t * p_data,
         } /* has adaptation field */
         /* Check the continuity of the stream. */
         i_dummy = ((p[3] & 0x0f) - p_es_demux->i_continuity_counter) & 0x0f;
-        if( i_dummy == 1 )
+        if( i_dummy == 1 || (b_psi && p_stream_demux->b_buggy_psi) )
         {
             /* Everything is ok, just increase our counter */
             (p_es_demux->i_continuity_counter)++;
