@@ -1,8 +1,8 @@
 /*****************************************************************************
  * vout.h: MacOS X interface plugin
  *****************************************************************************
- * Copyright (C) 2001, 2002 VideoLAN
- * $Id: vout.h,v 1.5 2003/01/31 02:53:52 jlj Exp $
+ * Copyright (C) 2001-2003 VideoLAN
+ * $Id: vout.h,v 1.10 2003/03/06 11:43:07 hartman Exp $
  *
  * Authors: Colin Delacroix <colin@zoy.org>
  *          Florian G. Pflug <fgp@phlo.org>
@@ -34,8 +34,10 @@
 - (void)setVout:(vout_thread_t *)_p_vout;
 - (vout_thread_t *)getVout;
 
+- (void)scaleWindowWithFactor: (float)factor;
 - (void)toggleFullscreen;
 - (BOOL)isFullscreen;
+- (void)updateTitle;
 
 - (BOOL)windowShouldClose:(id)sender;
 
