@@ -2,7 +2,7 @@
  * input_ext-plugins.c: useful functions for access and demux plug-ins
  *****************************************************************************
  * Copyright (C) 2001, 2002 VideoLAN
- * $Id: input_ext-plugins.c,v 1.27 2003/01/25 03:12:20 fenrir Exp $
+ * $Id: input_ext-plugins.c,v 1.30 2003/03/05 17:55:13 gbazin Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -145,7 +145,7 @@ void input_BuffersEnd( input_thread_t * p_input, input_buffers_t * p_buffers )
 
         if( p_buffers->i_allocated )
         {
-            msg_Err( p_input, "%d bytes have not been freed, "
+            msg_Err( p_input, "%u bytes have not been freed, "
                               "expect memory leak", p_buffers->i_allocated );
         }
 
@@ -494,6 +494,7 @@ ssize_t input_FillBuffer( input_thread_t * p_input )
     {
         vlc_mutex_unlock( &p_input->p_method_data->lock );
         msg_Err( p_input, "failed allocating a new buffer (decoder stuck?)" );
+        msleep( INPUT_IDLE_SLEEP );
         return -1;
     }
     p_buf->i_refcount = 1;
@@ -610,7 +611,7 @@ int input_AccessInit( input_thread_t * p_input )
 }
 
 /*****************************************************************************
- * input_AccessReinit: reinit structures after a random seek
+ * input_AccessReinit: reinit structures before a random seek
  *****************************************************************************/
 void input_AccessReinit( input_thread_t * p_input )
 {
